Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(253)

Unified Diff: remoting/host/ipc_video_frame_capturer.h

Issue 12047101: Move screen capturers from remoting/capturer to media/video/capturer/screen (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/ipc_desktop_environment.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/ipc_video_frame_capturer.h
diff --git a/remoting/host/ipc_video_frame_capturer.h b/remoting/host/ipc_video_frame_capturer.h
index ba5c51784d03c0d96590f009453d6f22a1073b75..681361b921ac2660623ec4d070367f324366d876 100644
--- a/remoting/host/ipc_video_frame_capturer.h
+++ b/remoting/host/ipc_video_frame_capturer.h
@@ -6,26 +6,29 @@
#define REMOTING_HOST_IPC_VIDEO_FRAME_CAPTURER_H_
#include "base/memory/ref_counted.h"
-#include "remoting/capturer/video_frame_capturer.h"
+#include "media/video/capture/screen/screen_capturer.h"
namespace IPC {
class Message;
} // namespace IPC
+namespace media {
+struct MouseCursorShape;
+} // namespace media
+
namespace remoting {
class DesktopSessionProxy;
-struct MouseCursorShape;
-// Routes VideoFrameCapturer calls though the IPC channel to the desktop session
-// agent running in the desktop integration process.
-class IpcVideoFrameCapturer : public VideoFrameCapturer {
+// Routes media::ScreenCapturer calls though the IPC channel to the desktop
+// session agent running in the desktop integration process.
+class IpcVideoFrameCapturer : public media::ScreenCapturer {
public:
explicit IpcVideoFrameCapturer(
scoped_refptr<DesktopSessionProxy> desktop_session_proxy);
virtual ~IpcVideoFrameCapturer();
- // VideoFrameCapturer interface.
+ // media::ScreenCapturer interface.
virtual void Start(Delegate* delegate) OVERRIDE;
virtual void Stop() OVERRIDE;
virtual void InvalidateRegion(const SkRegion& invalid_region) OVERRIDE;
@@ -33,14 +36,14 @@ class IpcVideoFrameCapturer : public VideoFrameCapturer {
// Called when a video frame has been captured. |capture_data| describes
// a captured frame.
- void OnCaptureCompleted(scoped_refptr<CaptureData> capture_data);
+ void OnCaptureCompleted(scoped_refptr<media::ScreenCaptureData> capture_data);
// Called when the cursor shape has changed.
- void OnCursorShapeChanged(scoped_ptr<MouseCursorShape> cursor_shape);
+ void OnCursorShapeChanged(scoped_ptr<media::MouseCursorShape> cursor_shape);
private:
- // Points to the delegate passed to VideoFrameCapturer::Start().
- VideoFrameCapturer::Delegate* delegate_;
+ // Points to the delegate passed to media::ScreenCapturer::Start().
+ media::ScreenCapturer::Delegate* delegate_;
// Wraps the IPC channel to the desktop session agent.
scoped_refptr<DesktopSessionProxy> desktop_session_proxy_;
« no previous file with comments | « remoting/host/ipc_desktop_environment.cc ('k') | remoting/host/ipc_video_frame_capturer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698